#
# spec file for package python-flake8-isort
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flake8-isort
Version:        6.1.1
Release:        1.3
Summary:        Plugin integrating isort in flake8
License:        GPL-2.0-only
Group:          Development/Languages/Python
URL:            https://github.com/gforcada/flake8-isort
Source:         https://files.pythonhosted.org/packages/source/f/flake8-isort/flake8_isort-%{version}.tar.gz
BuildRequires:  %{python_module flake8}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module isort >= 4.3.5}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module testfixtures}
BuildRequires:  %{python_module toml}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-flake8
Requires:       python-isort >= 4.3.5
Requires:       python-testfixtures
BuildArch:      noarch
%python_subpackages

%description
Use `isort`_ to check if the imports on your python files are sorted the way you expect.

%prep
%setup -q -n flake8_isort-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest ./run_tests.py

%files %{python_files}
%doc README.rst CHANGES.rst
%license LICENSE*
%{python_sitelib}/flake8_isort.py*
%pycache_only %{python_sitelib}/__pycache__/flake8_isort*
%{python_sitelib}/flake8_isort-%{version}.dist-info

%changelog
* Tue Dec  5 2023 Dirk Müller <dmueller@suse.com>
- update to 6.1.1:
  * Switch from `setup.cfg` to `setup.py`.
  * Switch from `setuptools` to `hatchling`.
  * Drop python 3.7 support.
  * Add preliminary support to Python 3.12.
* Mon Jan  2 2023 Dirk Müller <dmueller@suse.com>
- update to 6.0.0:
  * Drop isort 4.x support.
  * Add support for flake8 6.0.0.
  * Add `--isort-no-skip-gitignore` option to allow temporarily overriding
    the set
  value of isort's `skip_gitignore` option with `False`. This can cause
  flake8-isort to run significantly faster at the cost of making flake8-isort's
  behavior differ slightly from the behavior of `isort --check`. [gschaffner]
  * Fix broken `add_options` method [casperdcl]
  * Improve the config option is added and read back. [gforcada]
  * Bump plugin version. [gforcada]
  * Update dependencies. [gforcada]
  * Revamp GitHub actions. [gforcada]
  * Drop python 3.6, and add python 3.10. [gforcada]
  * Use linters and formatters to keep code sane and beautiful. [gforcada]
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 4.2.0
  * Fix compatibility with flake8 version 5.
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 4.1.1:
  * Support flake8 4.x
  * Switch from travis-ci to github actions
  * Drop python 2.7 support and 3.5 as well
* Tue Aug 11 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 4.0.0
  * support isort >= 5 [bnavigator, pkolbus]
* Mon Jul 13 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 3.0.1
  * Work around FailedToLoadPlugin exception by requiring isort 4.x.
    Likewise, pin the major version of all dependencies, to reduce
    risk of any future incompatibilities. [pkolbus]
- Update to version 3.0.0
  * Let isort search the configuration, rather than flake8-isort
    try to find it. [jnns]
* Sat Apr 11 2020 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, used by spec-cleaner
